MigrationExecutionResult class final

Result of migration execution.

Annotations
  • @immutable

Constructors

MigrationExecutionResult({required bool ok, required MigrationStatus status, String message = '', Map<String, dynamic> metadata = const <String, dynamic>{}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
metadata Map<String, dynamic>
final
ok bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status MigrationStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited