StorageDeprecationItem class final

Deprecation schedule item with owner/date.

Annotations
  • @immutable

Constructors

StorageDeprecationItem({required String id, required String description, required String owner, required DateTime targetDateUtc, required StorageDeprecationStage stage})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
owner String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage StorageDeprecationStage
final
targetDateUtc DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited