StorageObservabilityEvidence class final

Observability readiness evidence.

Annotations
  • @immutable

Constructors

StorageObservabilityEvidence({required bool hasStructuredLogs, required bool hasCorrelationIds, required bool hasDebugExportBundle, Set<String> availableMetrics = const <String>{}})
const

Properties

availableMetrics Set<String>
final
hasCorrelationIds bool
final
hasDebugExportBundle bool
final
hashCode int
The hash code for this object.
no setterinherited
hasStructuredLogs bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited