SyncQueuePolicy class final

Retry/backoff policy for namespace outbox replay.

Annotations
  • @immutable

Constructors

SyncQueuePolicy({int maxRetries = 3, int initialBackoffMs = 1000, int maxBackoffMs = 30000, int maxEntryAgeMs = 86400000})
const
SyncQueuePolicy.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
initialBackoffMs int
final
maxBackoffMs int
final
maxEntryAgeMs int
final
maxRetries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

backoffForAttempt(int attempt) Duration
exceedsMaxAge({required DateTime createdAtUtc, required DateTime nowUtc}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited