StorageCapabilities class final
Provider capability set used for profile negotiation.
- Annotations
-
- @immutable
Constructors
- StorageCapabilities({bool supportsDiff = false, bool supportsHistory = false, bool supportsRevisionMetadata = false, bool supportsManualConflictResolution = false, bool supportsBackgroundSync = false, bool supportsMigrationEndpoint = false})
-
const
-
StorageCapabilities.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsBackgroundSync → bool
-
final
- supportsComplexInteraction → bool
-
no setter
- supportsDiff → bool
-
final
- supportsHistory → bool
-
final
- supportsManualConflictResolution → bool
-
final
- supportsMigrationEndpoint → bool
-
final
- supportsRevisionMetadata → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
satisfies(
StorageCapabilities required) → bool -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- none → const StorageCapabilities