StorageObservabilityEvidence class final
Observability readiness evidence.
- Annotations
-
- @immutable
Constructors
Properties
-
availableMetrics
→ Set<
String> -
final
- hasCorrelationIds → bool
-
final
- hasDebugExportBundle → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasStructuredLogs → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- autoResolveRatioMetric → const String
- conflictRateMetric → const String
- migrationOutcomeMetric → const String
- queueDepthMetric → const String
- readLatencyMetric → const String
- recoveryReplayDurationMetric → const String
-
requiredMetrics
→ const Set<
String> - safeDegradeCountMetric → const String
- writeLatencyMetric → const String