SyncQueueState class final
Queue state persisted per namespace.
- Annotations
-
- @immutable
Constructors
-
SyncQueueState({List<
SyncOutboxEntry> outbox = const <SyncOutboxEntry>[], List<SyncOutboxEntry> deadLetter = const <SyncOutboxEntry>[], List<SyncConflictEntry> conflicts = const <SyncConflictEntry>[], List<String> appliedEntryIds = const <String>[]}) -
const
Properties
-
appliedEntryIds
→ List<
String> -
final
-
conflicts
→ List<
SyncConflictEntry> -
final
-
deadLetter
→ List<
SyncOutboxEntry> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
outbox
→ List<
SyncOutboxEntry> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< SyncOutboxEntry> ? outbox, List<SyncOutboxEntry> ? deadLetter, List<SyncConflictEntry> ? conflicts, List<String> ? appliedEntryIds}) → SyncQueueState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited